@@ -135,4 +135,33 @@ class UMnetequip(UMnetdb):
         table = 'ARADMIN1.UMNET_EQUIPMENT eq'
 
         sql = self._build_select(select, table, where=where)
-        return self._execute(sql)
\ No newline at end of file
+        return self._execute(sql)
+
+    def get_all_devices(self):
+        select = [  "bldg_code__ as bldg_code",
+                    "bldg",
+                    "room",
+                    "ip_address",
+                    "dns_name",
+                    "category",
+                    "types",
+                    "manufacturer",
+                    "serial_number",
+                    "billing_code_ as billing_code",
+                    "warehouse_item__ as warehouse_item",
+                    "st.descr as status",
+                    "sla_network",
+                    "address",
+                    "floor",
+                    "model_no_ as model_no",
+                    "customer_name",
+                    "mat_l_item_description",
+                    "rancid",
+                    "off_line",
+                 ]
+        table = 'ARADMIN1.UMNET_EQUIPMENT eq'
+        joins = ["join ARADMIN1.UMNET_EQUIPMENT_STATUS st on st.idnum=eq.status"]
+        where = ["eq.status != 3"]
+
+        sql = self._build_select(select, table,where=where, joins=joins)
+        return self._execute(sql)
