@@ -4,6 +4,61 @@ from .constants import I_ABBR
 import re
 from dns import resolver, reversename
 
+INTERFACE_SPEEDS = {
+    'et-': 40,
+    'xe-': 10,
+    'ge-': 1,
+
+    'Fo': 40,
+    'Twe': 25,
+    'Te': 10,
+    'Two': 2,
+    'Gi': 1,
+    'Fa': .1,
+}
+
+def interface_sort(input):
+    """
+    Meant to be passed as a sort function for a list of interface names, or a list
+    of dictionaries representing interface data
+
+    If you're dealing with a list of dictionaries, the port name must be keyed as "port"
+    or "name". If it's not, the function will throw an error.
+
+    It is assumed that all ports have at least a mod/port component (eg GiX/Y), and it will also
+    handle a slot/mod/number (eg GiX/Y/Z). "X" is weighted by 1000, "Y" by 100, and Z by 1.
+
+    """
+    if isinstance(input, dict):
+        if "port" in input:
+            port = input["port"]
+        elif "name" in input:
+            port = input["name"]
+        else:
+            raise KeyError(f"Unknown key for port list of dicts sort")
+    elif isinstance(input, str):
+        port = input
+
+    prefix_value = 0
+    for prefix, weight in INTERFACE_SPEEDS.items():
+        if port.startswith(prefix):
+            prefix_value = int(weight * 10000)
+
+    m = re.match(r'.+(\d+)/(\d+)/(\d+)$', port)
+    if m:
+        return(prefix_value + int(m.group(1))*1000 + int(m.group(2))*100 + int(m.group(3)))
+    
+    m = re.match(r'.+(\d+)/(\d+)$', port)
+    if m:
+        return(prefix_value + int(m.group(1))*100 + int(m.group(2)))
+
+    m = re.match(r'.+(\d+)$', port)
+    if m:
+        return(prefix_value + int(m.group(1)))
+    
+    return 0
+
+
 def get_env_vars(vars_list):
     '''
     Pull list of variables from the environment,
@@ -74,7 +129,7 @@ def reverse_resolve(ip):
     looks for a PTR record for an inputted IPv4 address
     '''
     try:
-        resolve = resolver.resolve(reversename.from_address(input_str),'PTR')
+        resolve = resolver.resolve(reversename.from_address(ip),'PTR')
     except:
         return False
     return resolve[0].to_text()
@@ -101,11 +156,18 @@ def resolve_name_or_ip(input_str):
     else:
         result['name'] = input_str
         result_type = 'ip'
+
+        # if no domain name was provided, tack on our standard domain
+        if "." not in input_str:
+            input_str += ".umnet.umich.edu"
+
         q_str = input_str
         q_type = 'A'
 
+    resolve = resolver.resolve(q_str, q_type)
     try:
         resolve = resolver.resolve(q_str, q_type)
+        print(resolve[0].to_text())
     except resolver.NXDOMAIN:
         resolve = False
         pass
@@ -140,4 +202,3 @@ def get_ncs_interface_name(port):
     # also need to remove ".0" from junos ports
     port = re.sub(r'\.0$','', port)
     return port
-            
